package com.bwie.alipay.controller;
import com.alipay.api.AlipayApiException;
import com.alipay.api.AlipayConstants;
import com.alipay.api.internal.util.AlipaySignature;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.bwie.alipay.service.AlimentPayService;
import com.bwie.alipay.service.AlipayWayService;
import com.bwie.alipay.utils.service.AlipayWay;
import com.bwie.alipay.utils.PayServive;
import com.bwie.alipay.vo.Alipay;
import com.bwie.common.domain.BuyOrder;
import com.bwie.common.domain.PaymentEntity;
import com.bwie.common.result.BizException;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationContext;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.nio.charset.StandardCharsets;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
@Slf4j
@RestController
public class AlipayWayController {
    @Autowired
    private AlipayWay alipayWay;
    @Autowired
    private AlipayWayService alipayWayService;//buyOrder
    @Autowired
    private AlimentPayService alimentPayService;//PaymentEntity

    @Autowired
    private ApplicationContext applicationContext;
    @ResponseBody
    @GetMapping("/pay")
    public String pay(Long buyOrderId,String type) throws AlipayApiException {
        BuyOrder buyOrder = alipayWayService.getOne(
                new LambdaQueryWrapper<BuyOrder>().eq(BuyOrder::getOrderId, buyOrderId));


        if(buyOrder.getOrderState().equals(3)){
            throw new BizException(500,"不能重复支付!!!!!");
        }
        PaymentEntity paymentEntity = PaymentEntity.builder()
                .ordersNumber(buyOrder.getOrderNumber())
                .userId(buyOrder.getUserId())
                .tradeMoney(buyOrder.getOrderPrice())
                .backTime(new Date())
                .tradeStatus(1).build();
        //添加到数据库
        alimentPayService.save(paymentEntity);


        alipayWayService.updateById(
                BuyOrder.builder()
                        .orderId(buyOrder.getOrderId())
                        .orderState(2).build()
        );
        PayServive bean = (PayServive)applicationContext.getBean(type);
        return bean.alipay(buyOrder);
    }

    @Resource
    private Alipay alipay;
    @Transactional
    @RequestMapping("/notifyUrl")
    public void notifyUrl(HttpServletRequest request, HttpServletResponse response) throws Exception {

        request.setCharacterEncoding("utf-8");

        HashMap<String, String> params = new HashMap<>(8);

        Map<String, String[]> requestParams = request.getParameterMap();

        for (Map.Entry<String, String[]> stringEntry : requestParams.entrySet()) {

            String[] values = stringEntry.getValue();

            String valueStr="";
            for (int i = 0; i < values.length; i++) {
                valueStr = (i == values.length - 1) ? valueStr + values[i]
                        : valueStr + values[i] + ",";
            }
            System.out.println("key="+stringEntry.getKey()+" value="+valueStr);
            params.put(stringEntry.getKey(), valueStr);
        }
        boolean signVerified = AlipaySignature.rsaCheckV1(params,alipay.getAlipayPublicKey(), AlipayConstants.CHARSET_UTF8, AlipayConstants.SIGN_TYPE_RSA2);
        if(!signVerified){
            log.error("验签失败!!!!");
        }
        String orderSn = new String(params.get("out_trade_no").getBytes(StandardCharsets.ISO_8859_1), StandardCharsets.UTF_8);
        BuyOrder buyOrder = alipayWayService.getOne(
                new LambdaQueryWrapper<BuyOrder>()
                        .eq(BuyOrder::getOrderNumber, orderSn)
        );
        if(buyOrder.getOrderState().equals(3)){
            throw new BizException(500,"已经支付成功，禁止重复回掉");
        }
        List<PaymentEntity> paymentEntityList = alimentPayService.list(
                new LambdaQueryWrapper<PaymentEntity>()
                        .eq(PaymentEntity::getOrdersNumber, buyOrder.getOrderNumber())
        );
        paymentEntityList.forEach(c->{
            if(c.getTradeStatus().equals(2)){
                throw new BizException(500,"已经支付成功，禁止重复回掉");
            }
        });
        paymentEntityList.forEach(c->{
            if(c.getTradeStatus().equals(1)){ //正在支付
                alimentPayService.updateById(
                        PaymentEntity.builder()
                                .tradeId(c.getTradeId())
                                .thirdStatus(2).build()
                ); //修改为已支付
            }
        });
        alipayWayService.updateById(
                buyOrder.builder()
                        .orderId(buyOrder.getOrderId())
                        .orderState(3).build()
        );
        response.setStatus(HttpServletResponse.SC_OK);
    }
}
