package com.bwie.authen.controller;
import com.bwie.authen.vo.AliveReq;
import com.bwie.authen.service.AuthenticationService;
import com.bwie.authen.vo.AuthenReq;
import com.bwie.authen.vo.IdCheckReq;
import com.bwie.common.result.Result;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.util.concurrent.ExecutionException;
@RestController
public class AuthenticationController {
    private final AuthenticationService authenService;
    public AuthenticationController(AuthenticationService authenService) {
        this.authenService = authenService;
    }

    /**
     * 解析身份证
     * @param side
     * @param url
     * @return
     * @throws IOException
     */
    @PostMapping("ocrScan")
    public Result ocrScan(@RequestParam String side,@RequestParam("file") MultipartFile url) throws IOException {
        Result result = authenService.ocrScan(side,url);
        return result;
    }

    /**
     * 单线程的验证,身份证正面,身份证反面,活体检测
     * @param img1
     * @param img2
     * @param movie
     * @param authenReq
     * @return
     * @throws ExecutionException
     * @throws InterruptedException
     */
    @PostMapping("commitAuthen")
    public Result commitAuthen(@RequestParam("face") MultipartFile img1,
                               @RequestParam("back") MultipartFile img2,
                               @RequestParam("file") MultipartFile movie,
                                AuthenReq authenReq) throws ExecutionException, InterruptedException {
        Result result = authenService.commitAuthen(img1,img2,movie,authenReq);
        return result;
    }

    /**
     * 照片上传
     * @param multipartFile
     * @return
     * @throws IOException
     */
    @PostMapping("upload")
    public Result upload(@RequestParam("file")MultipartFile multipartFile) throws IOException {
      String upload = authenService.upload(multipartFile);
        return Result.success(upload);
    }

    /**
     * 身份验证
     * @param ocrReq
     * @return
     */
    @PostMapping("idCheck")
    public Result idCheck(@RequestBody IdCheckReq ocrReq) {
        Result result = authenService.idCheck(ocrReq);
        return result;
    }

    /**
     * 视频上传校验
     * @param ocrReq
     * @return
     */
    @PostMapping("alive")
    public Result alive(@RequestBody AliveReq ocrReq) {
        Result result = authenService.alive(ocrReq);
        return result;
    }
}
