package com.bwie.authen.service.impl;

import com.bwie.authen.service.AuthenticationService;
import com.bwie.authen.util.*;
import com.bwie.authen.vo.*;
import com.bwie.common.result.Result;
import lombok.extern.log4j.Log4j2;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.io.Serializable;
import java.util.concurrent.CompletableFuture;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.ThreadPoolExecutor;

@Service
@Log4j2
public class AuthenticationServiceImpl implements AuthenticationService {

    private final OSSupload osSupload;
    private final IdCheckUtil idCheckUtil;
    private final OCRUtil ocrUtil;
    private final AliveUtil aliveUtil;
    private final ThreadPoolExecutorConfig config;

    public AuthenticationServiceImpl(OSSupload osSupload, IdCheckUtil idCheckUtil, OCRUtil ocrUtil, AliveUtil aliveUtil, ThreadPoolExecutorConfig config) {
        this.osSupload = osSupload;
        this.idCheckUtil = idCheckUtil;
        this.ocrUtil = ocrUtil;
        this.aliveUtil = aliveUtil;
        this.config = config;
    }


    /**
     * 身份证解析,解析正反面
     * @param side
     * @param url
     * @return
     * @throws IOException
     */
    @Override
    public Result ocrScan( String side, MultipartFile url) throws IOException {
        OCRResponse send = ocrUtil.send(side,url);
        return Result.success(send);
    }

    //验证校验,线程解决
    @Override
    public Result commitAuthen(MultipartFile img1, MultipartFile img2, MultipartFile movie, AuthenReq authenReq) throws ExecutionException, InterruptedException {
        ThreadPoolExecutor threadPoolExecutor = config.threadPoolExecutor();
        CompletableFuture<Integer> f1 = CompletableFuture.supplyAsync(() -> {
            IdCheckReq idCheckReq = new IdCheckReq();
            idCheckReq.setName(authenReq.getName());
            idCheckReq.setIdCardNo(authenReq.getIdCord());
            IdCheckResponse idcheck = idCheckUtil.idcheck(idCheckReq);
            Integer result = idcheck.getIdData().getResult();
            if(result!=0){
                return 1;
            }
            try {
                OCRResponse send = ocrUtil.send("face", img1);
                if(send.getNum().equals(authenReq.getIdCord())&&send.getName().equals(authenReq.getName())){
                    return 0;
                }
            } catch (IOException e) {
                throw new RuntimeException(e);
            }
          return 1;
        },threadPoolExecutor);

        CompletableFuture<? extends Serializable> f2= CompletableFuture.supplyAsync(() -> {

            String upload = null;
            try {
                upload = osSupload.upload(movie);
            } catch (IOException e) {
                throw new RuntimeException(e);
            }


            if(upload==null){
                return false;
            }
            //url添加数据库
            AliveReq aliveReq = new AliveReq();
            aliveReq.setUrl(upload);
            aliveReq.setMotions(authenReq.getMotions());
            AliveRes alive = aliveUtil.alive(aliveReq);
            String success = alive.getSuccess();
            return success;
        },threadPoolExecutor);

        CompletableFuture<Integer> f3 = CompletableFuture.supplyAsync(() -> {
            String upload = null;
            try {
                upload = osSupload.upload(img2);
            } catch (IOException e) {
                throw new RuntimeException(e);
            }
            String upload2 = null;
            try {
                upload2 = osSupload.upload(movie);
            } catch (IOException e) {
                throw new RuntimeException(e);
            }
            if(upload==null ||upload2==null){
                return 1;
            }
            //存入数据库
            return 0;
        },threadPoolExecutor);

        Integer i = f1.get();
        Serializable serializable = f2.get();
        Integer b1 = f3.get();

        if ((i == 0) && serializable.equals("true")||b1==0) {
            return Result.success();
        }
        return Result.error();
    }


    //图片上传
    @Override
    public String upload(MultipartFile multipartFile) throws IOException {
        return osSupload.upload(multipartFile);
    }
    //身份校验
    @Override
    public Result idCheck(IdCheckReq ocrReq) {
        IdCheckResponse idcheck = idCheckUtil.idcheck(ocrReq);
        return Result.success(idcheck);
    }
    //活体检测,上传视频
    @Override
    public Result alive(AliveReq ocrReq) {
        AliveRes alive = aliveUtil.alive(ocrReq);
        return Result.success(alive);
    }
}
