package com.bwie.authentication.util;
import cn.hutool.core.codec.Base64;
import cn.hutool.http.HttpUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.bwie.authentication.vo.OCRResponse;


import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.multipart.MultipartFile;


import java.io.IOException;


@Configuration
public class OCRUtil {
    @Value("${ocr.appcode}")
    private String appcode;
    @Value("${ocr.host}")
    private String host;
    @Value("${ocr.Content-Type}")
    private String contentType;
    @Value("${ocr.path}")
    private String path;

    public OCRResponse send(String side, MultipartFile url) throws IOException {


// 对图像进行base64编码

        String encode = Base64.encode(url.getBytes());

// 拼装请求body的json字符串
        JSONObject requestObj = new JSONObject();
        requestObj.put("image", encode);
        requestObj.put("side", side); // 假设ocrReq有getSide()方法返回要识别的身份证面（正/反）
// 如果API还有其他配置参数，可以从ocrReq中获取并添加到requestObj中

        String bodys = requestObj.toString();

        try {
            // 创建并执行POST请求
            String result = HttpUtil.createPost(host + path) // 不在URL中拼接查询参数，因为我们将它们放在请求体中
                    .header("Authorization", "APPCODE " + appcode)
                    .header("Content-Type", contentType) // 确保这里与headers中的Content-Type一致
                    .body(bodys) // 设置请求体
                    .execute()
                    .body();

            System.out.println("result = " + result);

            OCRResponse msgResponse = JSON.parseObject(result, OCRResponse.class);

            // 检查是否成功，而不是使用Assert（Assert通常用于测试）
            if (!msgResponse.getSuccess().equals("true")) {
                // 处理失败情况，例如记录日志或返回错误信息给调用者
                throw new RuntimeException("扫描失败" ); // 假设OCRResponse有一个getErrorMessage方法
            }

            // 成功处理逻辑
            return msgResponse;
        } catch (Exception e) {
            // 处理异常，例如记录日志或返回错误信息给调用者
            e.printStackTrace();
            throw new RuntimeException("请求OCR服务时发生异常", e);
        }

    }




}









