package com.bwie.kill.service.impl;

import cn.hutool.core.util.IdUtil;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.bwie.common.redis.RedisCache;
import com.bwie.common.result.PageResult;
import com.bwie.common.utils.StringUtils;
import com.bwie.kill.domain.KillGoods;
import com.bwie.kill.domain.request.PagesUtil;
import com.bwie.kill.domain.request.VoKillGoodsRequest;
import com.bwie.kill.mapper.KillGoodsMapper;
import com.bwie.kill.service.KillGoodsService;
import org.redisson.api.RedissonClient;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
public class KillGoodsServiceImpl extends ServiceImpl<KillGoodsMapper, KillGoods>
        implements KillGoodsService {
    @Autowired
    private RedisCache redisCache;
    @Autowired
    private RedissonClient redissonClient;

    @Override
    public PageResult<KillGoods> getKillGoodsList(VoKillGoodsRequest req) {

        if (StringUtils.isAllBlank(req.getConfigTitle(),req.getGoodsInfo()) && req.getActivityStatus() == null){

            if (redisCache.hasKey("listPage"+req.getPageNum())){
                String cacheObject = redisCache.getCacheObject("listPage" + req.getPageNum());
                PagesUtil pagesUtil = JSONObject.parseObject(cacheObject, PagesUtil.class);
                return PageResult.toPageResult(pagesUtil.getTotal(),pagesUtil.getList());
            }else {
                IPage<KillGoods> page = new Page<>(req.getPageNum(), req.getPageSize());
                IPage<KillGoods> iPage = page(page);
                PagesUtil pagesUtil = PagesUtil.builder().total(iPage.getPages())
                        .list(iPage.getRecords())
                        .build();
                redisCache.setCacheObject("listPage"+req.getPageNum(),JSONObject.toJSONString(pagesUtil));

                return PageResult.toPageResult(iPage.getPages(),iPage.getRecords());
            }

        }else {
            IPage<KillGoods> page = new Page<>(req.getPageNum(), req.getPageSize());
            LambdaQueryWrapper<KillGoods> queryWrapper = new LambdaQueryWrapper<KillGoods>();
            if (req.getActivityStatus() != null){
                queryWrapper.eq(KillGoods::getActivityStatus, req.getActivityStatus());
            }
            if (StringUtils.isNotBlank(req.getConfigTitle())){
                queryWrapper.eq(KillGoods::getConfigTitle, req.getConfigTitle());
            }
            if (StringUtils.isNotBlank(req.getGoodsInfo())){
                String str = req.getGoodsInfo();
                if (str.matches("\\d+")){
                    queryWrapper.eq(KillGoods::getId,req.getGoodsInfo());
                }else {
                    queryWrapper.like(KillGoods::getGoodsName,req.getGoodsInfo());
                }
            }

            IPage<KillGoods> iPage = page(page, queryWrapper);
            return PageResult.toPageResult(iPage.getPages(),iPage.getRecords());
        }

    }
}
