package com.bwie.order.controller;

import com.alibaba.fastjson2.util.DateUtils;
import com.alipay.api.AlipayApiException;
import com.alipay.api.internal.util.AlipaySignature;
import com.bwie.common.result.Result;
import com.bwie.order.service.TextService;
import com.bwie.order.service.TradeService;
import com.bwie.order.vo.AliPay;
import com.bwie.order.vo.FindTrade;
import com.bwie.order.vo.PayReq;
import lombok.extern.log4j.Log4j2;
import org.springframework.context.ApplicationContext;

import javax.servlet.http.HttpServletRequest;
import java.io.UnsupportedEncodingException;
import java.math.BigDecimal;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

@RestController
@Log4j2
public class PayController {


    private final TradeService tradeService;
    private final AliPay aliPay;
    private final ApplicationContext appletContext;


    public PayController( TradeService tradeService, AliPay aliPay, ApplicationContext appletContext) {

        this.tradeService = tradeService;
        this.aliPay = aliPay;

        this.appletContext = appletContext;
    }

    @PostMapping("pay")
    public Result pay(@RequestBody PayReq payReq) throws AlipayApiException {
        Result<String> stringResult = tradeService.addTrade(payReq);
        String data = stringResult.getData();
        TextService bean = (TextService) appletContext.getBean(payReq.getTradeType());
        return bean.pay(payReq.getOrdersMoney(),data);
    }

    /**
     * 支付宝验签方法
     *
     * @param request
     * @return
     * @throws AlipayApiException
     * @throws UnsupportedEncodingException
     */
    @ResponseBody
    @PostMapping("/payed/notify")
    public Result handleAliPayed( HttpServletRequest request) throws AlipayApiException, UnsupportedEncodingException {



            System.out.println("=========支付宝异步回调========");
            Map<String, String> params = new HashMap<>();
            Map<String, String[]> requestParams = request.getParameterMap();
            for (String name : requestParams.keySet()) {
                params.put(name, request.getParameter(name));
                // System.out.println(name + " = " + request.getParameter(name));
            }
//            String tradeNo = params.get("out_trade_no");
//            String gmtPayment = params.get("gmt_payment");
//            String alipayTradeNo = params.get("trade_no");

            String sign = params.get("sign");
            String content = AlipaySignature.getSignCheckContentV1(params);
            boolean checkSignature = AlipaySignature.rsa256CheckContent(content, sign, aliPay.getAlipayPublicKey(), "UTF-8"); // 验证签名
            // 支付宝验签
            if (checkSignature) {
                // 验签通过
                System.out.println("交易名称: " + params.get("subject"));
                System.out.println("交易状态: " + params.get("trade_status"));
                System.out.println("支付宝交易凭证号: " + params.get("trade_no"));
                System.out.println("商户订单号: " + params.get("out_trade_no"));
                System.out.println("交易金额: " + params.get("total_amount"));
                System.out.println("买家在支付宝唯一id: " + params.get("buyer_id"));
                System.out.println("买家付款时间: " + params.get("gmt_payment"));
                System.out.println("买家付款金额: " + params.get("buyer_pay_amount"));


//                params.get("buyer_id");
                String s = params.get("gmt_payment");
                Date date = DateUtils.parseDate(s, "yyyy-MM-dd HH:mm:ss");
                BigDecimal totalAmount = new BigDecimal(params.get("total_amount"));
//                long l = IdUtil.getSnowflake(1, 1).nextId();
                //执行逻辑
                 //保存交易流水  返回success
                FindTrade build = FindTrade.builder()
                        .tradeNum(params.get("out_trade_no"))
                        .thirdMessage(params.get("subject"))
                        .thirdNum(params.get("trade_no"))
                        .thirdStatus(params.get("trade_status"))
                        .backTime(date)
                        .updTime(new Date())
                        .tradeMoney(totalAmount)
                        .build();
               return tradeService.updtrade(build);
                //调用用户服务加积分
            }else {
                return Result.error("验签失败");
            }
//            return Result.success("支付成功");
        }

        @GetMapping("find")
        public Result find(){
            Result result = tradeService.syncTrade();
            return result;
        }





}
