package com.bwie.order.service.impl;

import cn.hutool.core.util.IdUtil;
import com.alipay.api.AlipayApiException;
import com.bwie.common.domain.Order;
import com.bwie.common.domain.Trade;
import com.bwie.common.remote.RemoteLoginService;
import com.bwie.common.result.Result;
import com.bwie.order.mapper.TradeMapper;
import com.bwie.order.service.OrdService;
import com.bwie.order.service.TradeService;
import com.bwie.order.util.FindSyncTrade;
import com.bwie.order.vo.*;
import org.springframework.stereotype.Service;
import org.springframework.util.Assert;
import org.springframework.util.CollectionUtils;

import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

@Service
public class TradeServiceImpl implements TradeService {
    private final RemoteLoginService remoteLoginService;
    private final OrdService ordService;
    private final TradeMapper tradeMapper;
    private final FindSyncTrade findSyncTrade;

    public TradeServiceImpl(RemoteLoginService remoteLoginService, OrdService ordService, TradeMapper tradeMapper, FindSyncTrade findSyncTrade) {
        this.remoteLoginService = remoteLoginService;
        this.ordService = ordService;
        this.tradeMapper = tradeMapper;
        this.findSyncTrade = findSyncTrade;
    }

    @Override
    public Result<String> addTrade(PayReq payReq) {
        Order repay = ordService.show(payReq.getOrdersNumber());

        if(null==repay){
            return Result.error("订单不存在");
        }

        List<Trade> findord = tradeMapper.findord(payReq.getOrdersNumber());
        if(!CollectionUtils.isEmpty(findord)){
            findord.stream().forEach(c ->{
                Assert.isTrue(c.getTradeStatus()==1||c.getTradeStatus()==4,"请检查支付状态");
//                Assert.isTrue(c.getTradeStatus()==3,"订单已支付");
            });
        }
        long l = IdUtil.getSnowflake(1, 1).nextId();

        TradeReq tradeReq = new TradeReq();
        tradeReq.setTradeNum(String.valueOf(l));
        tradeReq.setUpdTime(new Date());
        tradeReq.setCreateTime(new Date());
        tradeMapper.addtrade(payReq,tradeReq);
        return  Result.success(tradeReq.getTradeNum());
    }

    @Override
    public Result updtrade(FindTrade build) {
        Trade succtrade = tradeMapper.succtrade(build.getTradeNum());
        if(null==succtrade){
            return Result.error("交易不存在");
        }
        if(build.getTradeMoney().compareTo(succtrade.getTradeMoney())!=0){
            return Result.error("交易钱款不一致");
        }
        if(succtrade.getTradeStatus()!=2 && succtrade.getTradeStatus()!=1){
            return Result.error("重复回调");
        }

        if("WAIT_BUYER_PAY".equals(build.getThirdStatus())){
            return Result.error("交易金额结果不明确");
        }

        if("TRADE_SUCCESS".equals(build.getThirdStatus())){
            build.setTradeStatus(3);
        }else {
            build.setTradeStatus(4);
        }

        tradeMapper.updtrade(build);
        UpdOrder updOrder = new UpdOrder();
        updOrder.setOrdersStatus(OrderStatusEnum.PAYED.getCode());
        updOrder.setOrdersNumber(succtrade.getOrdersNumber());
        ordService.updStatus(updOrder);
        long l = Long.parseLong(succtrade.getOrdersNumber().substring(21));
        remoteLoginService.addpoint(l,100);
        return Result.success("修改状态完成");
    }
    public Result syncTrade() {
        List<Trade> trades = tradeMapper.syncFind();
        if(trades==null){
            return Result.success("均支付完成");
        }
        List<Result> use = trades.stream().map(c -> {
            Ament ament = new Ament();
            ament.setThirdNum(c.getThirdNum());
            ament.setTradeNum(c.getTradeNum());
            try {
                Result<FindTrade> findTradeResult = findSyncTrade.AlipayTradeQuery(ament);
                if (findTradeResult.isSuccess()) {
                    FindTrade data = findTradeResult.getData();
                    Result addtrade = updtrade(data);
                    return addtrade;
                } else {
                    return Result.error("支付宝查询调用失败");
                }
            } catch (AlipayApiException e) {
                throw new RuntimeException(e);
            }
        }).collect(Collectors.toList());
        use.stream().forEach(c->System.out.println("c = " + c));
        return Result.success("同步完成");
    }
}
