package com.bwie.order.util;

import com.alipay.api.AlipayApiException;
import com.alipay.api.AlipayClient;
import com.alipay.api.AlipayConfig;
import com.alipay.api.DefaultAlipayClient;
import com.alipay.api.domain.AlipayTradeQueryModel;
import com.alipay.api.request.AlipayTradeQueryRequest;
import com.alipay.api.response.AlipayTradeQueryResponse;
import com.bwie.common.result.Result;
import com.bwie.order.vo.AliPay;
import com.bwie.order.vo.Ament;
import com.bwie.order.vo.FindTrade;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

@Component
public class FindSyncTrade {
    private final AliPay aliPay;

    public FindSyncTrade(AliPay aliPay) {
        this.aliPay = aliPay;
    }


    public Result<FindTrade> AlipayTradeQuery(Ament ament) throws AlipayApiException {


        // 初始化SDK
        AlipayClient alipayClient = new DefaultAlipayClient(getAlipayConfig());

        // 构造请求参数以调用接口
        AlipayTradeQueryRequest request = new AlipayTradeQueryRequest();
        AlipayTradeQueryModel model = new AlipayTradeQueryModel();

        // 设置订单支付时传入的商户订单号
        model.setOutTradeNo(ament.getTradeNum());

        // 设置查询选项
        List<String> queryOptions = new ArrayList<String>();
        queryOptions.add("trade_settle_info");
        model.setQueryOptions(queryOptions);

        // 设置支付宝交易号
        model.setTradeNo(ament.getThirdNum());

        request.setBizModel(model);
        AlipayTradeQueryResponse response = alipayClient.execute(request);
        System.out.println(response.getBody());

        if (response.isSuccess()) {
            System.out.println("调用成功");
            BigDecimal totalAmount = new BigDecimal(response.getTotalAmount());

            FindTrade find = FindTrade.builder()
                    .tradeMoney(totalAmount)
                    .tradeNum(response.getOutTradeNo())
                    .thirdMessage("补偿查询")
                    .thirdNum(response.getTradeNo())
                    .thirdStatus(response.getTradeStatus())
                    .backTime(response.getSendPayDate())
                    .updTime(new Date())
                    .build();


            return Result.success(find);
        } else {
            System.out.println("调用失败");
            return Result.error("调用失败");
            // sdk版本是"4.38.0.ALL"及以上,可以参考下面的示例获取诊断链接
            // String diagnosisUrl = DiagnosisUtils.getDiagnosisUrl(response);
            // System.out.println(diagnosisUrl);
        }

    }
        private  AlipayConfig getAlipayConfig() {
            String privateKey  = aliPay.getPrivateKey();
            String alipayPublicKey = aliPay.getAlipayPublicKey();
            AlipayConfig alipayConfig = new AlipayConfig();
            alipayConfig.setServerUrl(aliPay.getServerUrl());
            alipayConfig.setAppId(aliPay.getAppId());
            alipayConfig.setPrivateKey(privateKey);
            alipayConfig.setFormat(aliPay.getFormat());
            alipayConfig.setAlipayPublicKey(alipayPublicKey);
            alipayConfig.setCharset(aliPay.getCharset());
            alipayConfig.setSignType(aliPay.getSignType());
            return alipayConfig;
        }

}
