package com.bwie.order.util;

import com.alibaba.fastjson.JSON;
import com.alipay.api.AlipayApiException;
import com.alipay.api.AlipayClient;
import com.alipay.api.AlipayConfig;
import com.alipay.api.DefaultAlipayClient;
import com.alipay.api.diagnosis.DiagnosisUtils;
import com.alipay.api.domain.AlipayTradePagePayModel;
import com.alipay.api.request.AlipayTradePagePayRequest;
import com.alipay.api.response.AlipayTradePagePayResponse;
import com.bwie.order.vo.AliPay;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;

@Component
public class PayUtil {
    private final AliPay aliPay;

    public PayUtil(AliPay aliPay) {
        this.aliPay = aliPay;
    }

    public String pay(BigDecimal ordersPrice,String ordersNumber) throws AlipayApiException {
        String privateKey = aliPay.getPrivateKey();
        String alipayPublicKey = aliPay.getAlipayPublicKey();
        AlipayConfig alipayConfig = new AlipayConfig();
        alipayConfig.setServerUrl(aliPay.getServerUrl());
        alipayConfig.setAppId(aliPay.getAppId());
        alipayConfig.setPrivateKey(privateKey);
        alipayConfig.setFormat(aliPay.getFormat());
        alipayConfig.setAlipayPublicKey(alipayPublicKey);
        alipayConfig.setCharset(aliPay.getCharset());
        alipayConfig.setSignType(aliPay.getSignType());
        AlipayClient alipayClient = new DefaultAlipayClient(alipayConfig);
        AlipayTradePagePayRequest request = new AlipayTradePagePayRequest();
        AlipayTradePagePayModel model = new AlipayTradePagePayModel();
        model.setOutTradeNo(ordersNumber);
        model.setTotalAmount(JSON.toJSONString(ordersPrice));
        model.setSubject("发布");
        model.setProductCode("FAST_INSTANT_TRADE_PAY");
        request.setBizModel(model);
        //异步接收地址，仅支持http/https，公网可访问
        request.setNotifyUrl(aliPay.getNotifyUrl());
        //同步跳转地址，仅支持http/https
        //request.setReturnUrl("http://localhost:9003/show");
        //AlipayTradePagePayResponse response = alipayClient.pageExecute(request, "POST");
        // 如果需要返回GET请求，请使用
         AlipayTradePagePayResponse response = alipayClient.pageExecute(request, "GET");
        String pageRedirectionData = response.getBody();
        System.out.println(pageRedirectionData);
        if (response.isSuccess()) {
            System.out.println("调用成功");
        } else {
            //System.out.println("调用失败");
            // sdk版本是"4.38.0.ALL"及以上,可以参考下面的示例获取诊断链接
            String diagnosisUrl = DiagnosisUtils.getDiagnosisUrl(response);
            System.out.println(diagnosisUrl);
            return "调用失败";
        }

        return pageRedirectionData;
}

}
